@@ -88,6 +88,7 @@ public class CXFActivator extends HousekeepingActivator {
 
     @Override
     protected void startBundle() throws Exception {
+        Services.setServiceLookup(this);
         final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(CXFActivator.class);
         try {
             log.info("Starting Bundle: com.openexchange.soap.cxf");
@@ -124,7 +125,7 @@ public class CXFActivator extends HousekeepingActivator {
                                     httpService.unregister(servletAlias);
                                     alias3 = null;
                                 }
-                            } catch (final Exception e) {
+                            } catch (Exception e) {
                                 // Ignore
                             }
                         }
@@ -132,7 +133,7 @@ public class CXFActivator extends HousekeepingActivator {
                         if (null != collector) {
                             try {
                                 collector.close();
-                            } catch (final Exception e) {
+                            } catch (Exception e) {
                                 // Ignore
                             }
                             this.collector = null;
@@ -235,11 +236,11 @@ public class CXFActivator extends HousekeepingActivator {
                              * Return tracked HTTP service
                              */
                             return httpService;
-                        } catch (final ServletException e) {
+                        } catch (ServletException e) {
                             log.error("Couldn't register CXF Servlet", e);
-                        } catch (final NamespaceException e) {
+                        } catch (NamespaceException e) {
                             log.error("Couldn't register CXF Servlet", e);
-                        } catch (final RuntimeException e) {
+                        } catch (RuntimeException e) {
                             if (servletRegistered) {
                                 try {
                                     httpService.unregister(alias);
@@ -249,7 +250,7 @@ public class CXFActivator extends HousekeepingActivator {
                                         httpService.unregister(servletAlias);
                                         alias3 = null;
                                     }
-                                } catch (final Exception e1) {
+                                } catch (Exception e1) {
                                     // Ignore
                                 }
                             }
@@ -258,7 +259,7 @@ public class CXFActivator extends HousekeepingActivator {
                                 if (null != collector) {
                                     try {
                                         collector.close();
-                                    } catch (final Exception e1) {
+                                    } catch (Exception e1) {
                                         // Ignore
                                     }
                                     this.collector = null;
@@ -272,10 +273,16 @@ public class CXFActivator extends HousekeepingActivator {
                 };
                 track(HttpService.class, trackerCustomizer);
                 openTrackers();
-        } catch (final Exception e) {
+        } catch (Exception e) {
             log.error("", e);
             throw e;
         }
     }
 
+    @Override
+    protected void stopBundle() throws Exception {
+        super.stopBundle();
+        Services.setServiceLookup(null);
+    }
+
 }
